PickerAdapter<T> class abstract

选择器数据适配器

Implementers

Constructors

PickerAdapter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isLinkage → bool
no setter
length → int
Content length of current column
no setter
maxLevel → int
no setter
picker ↔ Picker?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
no setter

Methods

buildItem(BuildContext context, int index) → Widget
doSelect(int column, int index) → void
doShow() → void
getColumnFlex(int column) → int
getIsLinkage() → bool
getLength() → int
getMaxLevel() → int
getSelectedValues() → List<T>
getText() → String
initSelects() → void
makeText(Widget? child, String? text, bool isSel) → Widget
makeTextEx(Widget? child, String text, Widget? postfix, Widget? suffix, bool isSel) → Widget
needUpdatePrev(int curIndex) → bool
是否需要更新前面的列 Need to update previous columns
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyDataChanged() → void
通知适配器数据改变
setColumn(int index) → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited